


## 环境安装
```bash

conda create -n NepTrainKit python=3.10
conda activate NepTrainKit
pip install -r requirements.txt 

```


## 教程和演示
https://www.bilibili.com/video/BV1CrU7YUE3Z/

## 压缩打包
tar -caf NepTrainKit.linux.tar.gz -C NepTrainKit .
 